@@ -1,4 +1,4 @@
-use ansi_term::Style;
+use ansiterm::Style;
 
 use crate::fs::fields as f;
 use crate::output::cell::TextCell;
@@ -16,7 +16,7 @@ pub mod test {
     use crate::output::cell::TextCell;
     use crate::fs::fields as f;
 
-    use ansi_term::Colour::*;
+    use ansiterm::Colour::*;
 
 
     #[test]
